#!/bin/sh

###############################################################################
##                SETUP STAPI DEVICE NAME ENVIRONMENT VARIABLES              ##
###############################################################################

# Verify if root module is specified
# ----------------------------------
if [ -z "$MODULES_INSTALL_DIR" ] ; then
 export MODULES_INSTALL_DIR=/root/modules
fi

# Set the modules list path
# -------------------------
if [ -f $MODULES_INSTALL_DIR/unload_modules_list_32BITS.txt ]; then
 UNLOAD_MODULES_LIST=$MODULES_INSTALL_DIR/unload_modules_list_32BITS.txt
fi

###############################################################################
##                          SETUP DIRECTORY ACCESS                           ##
###############################################################################

# Verify if modules list exist
# ----------------------------
if [ ! -f $UNLOAD_MODULES_LIST ] ; then
 echo "$UNLOAD_MODULES_LIST does not exist"
 exit
fi

###############################################################################
##                          MODULE REMOVE PROCEDURE                          ##
###############################################################################

# Remove separate STAPI modules
# -----------------------------
remove_separated_modules()
{
 cat $UNLOAD_MODULES_LIST | grep -v "^#" | (while read mode mod_file node_name param; do
 if [ "$mode" != "-" ] ; then
   continue
 fi
 if [ ! -f $MODULES_INSTALL_DIR/$mod_file ] ; then
   continue
 fi
 mod_file=${mod_file%.ko}
 output=$(rmmod $mod_file 2>&1 | cat)
 [ "$output" != "" ] && { echo "$output" | grep "ERROR: " >/dev/null && echo "Warning : $mod_file is busy or not in /proc/devices" || { echo "$output" ; exit 1 ; } ; }
 if [ "$node_name" != "-" ] ; then
  rm -f /dev/stapi/$node_name
 fi
 done)
 # lxload is unloaded after loading video/audio binary, so deleting explicitly
 rm -f /dev/stapi/lxload
}

# Remove unique STAPI module
# --------------------------
remove_unified_module()
{
 # Removing STAPI modules
 echo "* Removing/unloading STAPI Module"
 if [ "$1" != "no_stapi_ioctl" ] ; then
  rmmod stapi_ioctl || return 1
 fi
 rmmod stapi_core || return 1

 echo "* Removing Multicom"
 rmmod $MODULES_INSTALL_DIR/mme_user.ko    || return 1
 rmmod $MODULES_INSTALL_DIR/mme.ko         || return 1
 rmmod $MODULES_INSTALL_DIR/embxmailbox.ko || return 1
 rmmod $MODULES_INSTALL_DIR/embx.ko        || return 1
 rmmod $MODULES_INSTALL_DIR/ics_user.ko    || return 1
 rmmod $MODULES_INSTALL_DIR/ics.ko         || return 1
}

# Choose between removing several or unified module
# ------------------------------------------------------------
if [ $# -eq 0 ] || [ "$1" != "not_unified" ]; then
 if [ -f "$MODULES_INSTALL_DIR/stapi_core_stripped.ko" ] && [ -f "$MODULES_INSTALL_DIR/stapi_ioctl_stripped.ko" ]; then
  remove_unified_module $1
 else
  remove_separated_modules
 fi
else
 remove_separated_modules
fi
