#!/bin/sh
# $1 - base URL for getting option certificate and md5 checksum for it


max_enc_size=5400
max_cert_size=4096

to_upper()
{
    export $1=`echo $2 | tr '[:lower:]' '[:upper:]'`
}

write_options()
{ # $1 - base64 encoded certificate file. $2 - md5 checksum of binary certificate.
    base64 -d $1 > /ram/opt.bin 2>/dev/null
    sum=`md5sum /ram/opt.bin | awk '{print $1}' 2>/dev/null`
    to_upper sum $sum
    sum2=$2
    to_upper sum2 $sum2
    #echo "sum: $sum. sum2: $sum2"
    if [ "$sum" != "$sum2" ] ; then
        echo "ERROR checksum mismatch."
        exit 2
    fi
    erase_size=`cat /proc/mtd | grep mtd2 | awk '{printf "0x%s", $3}'`
    erase_size=$((erase_size))
    if [ $erase_size -lt $max_cert_size ] ; then
	echo "ERROR writing mtd."
	exit 1
    fi
    dd if=/dev/mtd2 of=/ram/non-opt.bin bs=1 skip=$max_cert_size count=$((erase_size-max_cert_size)) 2>/dev/null 1>/dev/null
    flash_erase /dev/mtd2 0 1 > /dev/null 2>&1
    #cat /ram/non-opt.bin >> /ram/opt.bin
    dd if=/ram/non-opt.bin of=/ram/opt.bin conv=notrunc bs=$max_cert_size seek=1  2>/dev/null 1>/dev/null
    dd if=/ram/opt.bin of=/dev/mtd2 > /dev/null 2>&1
    rm /ram/opt.bin /ram/non-opt.bin
}

if [ "$1" == "" ]; then
    echo "ERROR not enough arguments."
    exit 1
fi

tmpfile=/ram/opt_enc.bin
md5file=/ram/opt_bin.md5

MAC=`dd if=/dev/mtdblock0 bs=1 count=30 skip=$((327520+32)) 2>/dev/null | strings -n1`
if [ "$MAC" == "" ] ; then
    echo "ERROR fetching MAC address."
    exit 1;
fi
to_upper MAC $MAC
MAC=`echo -n $MAC | sed 's/://g'`

/bin/wget $1/$MAC.cert  -O /dev/stdout 2>/dev/null | dd of=$tmpfile bs=1 count=$max_enc_size 2>/dev/null 1>/dev/null
size=`wc -c $tmpfile | awk '{printf $1}'`
if [ "$size" == "0" ] ; then
    echo "ERROR getting option certificate."
    exit 2
fi
/bin/wget $1/$MAC.md5  -O /dev/stdout 2>/dev/null | dd of=$md5file bs=1 count=100 2>/dev/null 1>/dev/null
md5_sum=`cat $md5file | awk '{printf $1}'`
#to_upper md5_sum $md5_sum

write_options $tmpfile $md5_sum

rm $tmpfile $md5file
echo -n "OK"
exit 0